# coding: UTF-8

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import os

import tensorflow as tf

WEIGHTS = ['Reg', 'Light', 'Medium']


def _is_selected(dir):
  for weight in WEIGHTS:
    if weight in dir:
      return True

  return False


def load_dataset(base_dir, image_size):
  def _read_image(file_path):
    image = tf.image.decode_jpeg(tf.read_file(file_path), channels=1)
    image = tf.image.resize_images(image, (image_size, image_size))

    # -1.0 〜 1.0 に正規化
    image = image / (255 / 2.0) - 1.0

    return image

  image_path_list = []

  for dir, _, files in os.walk(base_dir):
    if _is_selected(dir):
      image_path_list.extend(os.path.join(dir, file) for file in files)

  image_path_list = list(filter(
    lambda path: path.endswith('.jpg'), image_path_list))

  return tf.data.Dataset.from_tensor_slices(image_path_list) \
    .map(_read_image)
